<?php

if ( ! defined('EXT')) exit('Invalid file request');


/**
 *  MX TinyBrowser Field Class for BK FieldFrame
 *
 * @package  FieldFrame
 * @author    Max Lazar <max@wiseupstudio.com>
 * @copyright Copyright (c) 2009 Max Lazar
 * @license   http://creativecommons.org/licenses/by-sa/3.0/ Attribution-Share Alike 3.0 Unported
 */
class Mx_tinybrowser_field extends Fieldframe_Fieldtype {

	/**
	 * Fieldtype Info
	 * @var array
	 */
	var $info = array(
		'name'     => 'MX TinyBrowser Field',
		'version'  => '0.009g_dark ',
		'desc'     => 'Provides a TinyBrowser in stand-alone mode and with TinyMCE support',
		'docs_url' => 'http://wiseupstudio.com/'
	
	);

	/**
	 * Default Site Settings
	 * @var array
	 */
	var $default_field_settings = array(
		'options' => '',
		'upload_type' => 'images',
		'preferences' => '',
		'field_type' => 'stand',
		'config_file' => '',
		'allowupload' => 'true',
		'allowedit'		=> 'true',
		'allowdelete'		=> 'true',
		'allowfolders'		=> 'true',
	);

	var $default_cell_settings = array(
		'options' => '',
		'upload_type' => 'share',
		'preferences' => '',
		'field_type' => 'stand_alone',
		'config_file' => '',
		'allowupload' => 'true',
		'allowedit'		=> 'true',
		'allowdelete'		=> 'true',
		'allowfolders'		=> 'true',
	);
	
	var $default_site_settings = array(
		'allowupload' => 'true',
		'allowedit'		=> 'true',
		'allowdelete'		=> 'true',
		'allowfolders'		=> 'true',
		'cleanfilename'		=> 'true',
		'field_type' => 'stand',
		'pagination'		=> '0', // File Pagination - split results into pages (0 is none)
		'image_view'		=> 'thumb', //thumb, detail
		'flt_image'		=> '*.jpg, *.jpeg, *.gif, *.png', // Image file types
		'flt_media'		=>  '*.swf, *.dcr, *.mov, *.qt, *.mpg, *.mp3, *.mp4, *.mpeg, *.avi, *.wmv, *.wm, *.asf, *.asx, *.wmx, *.wvx, *.rm, *.ra, *.ram', // Media file types
		'flt_file'		=>  '*.*',// Other file types
		'thumbquality'		=> 80,
		'imagequality'		=> 80,
		'thumbsize'		=> 80,
		'resize_width'		=> 0, // Image automatic resize on upload (0 is no resize)
		'resize_height'		=> 0,
		'tinymce_url' 	=> '',
		'script_block' => '<script type="text/javascript" src="/tiny_mce/tiny_mce.js" charset="utf-8"></script>',
		'language' 	=> 'en',
		);
		
    // Hooks

	var $hooks = array(
		'show_full_control_panel_end' => array('priority' => 99, 'method' => 'show_full_control_panel_end')
	);
	
    // ...


	
	/**
	 * Display Field
	 * 
	 * @param  string  $field_name      The field's name
	 * @param  mixed   $field_data      The field's current value
	 * @param  array   $field_settings  The field's settings
	 * @return string  The field's HTML
	 */
	function display_field($field_name, $field_data, $field_settings)
	{
        global $DSP, $IN,$SESS,  $LANG;
        $this->include_css('styles/jquery.fancybox.css');
		$this->include_css('styles/mx_tinybrowser_field.css');
        $this->include_js('scripts/jquery.easing.1.3.js');
		$this->include_js('scripts/jquery.fancybox-1.2.1.js');
		$this->include_js('scripts/jquery.livequery.js');
		$this->include_js('scripts/mx_tinybrowser_field.js');

        $LANG->fetch_language_file('mx_tinybrowser_field');
		
		$r=""; 
		if ($field_settings['preferences'] !='' ) {	
		
			$edit_field = false;
			
			if($IN->GBL('M', 'GET') == 'blog_admin' AND $IN->GBL('P', 'GET') == 'edit_field') {
				$edit_field = true;
			}
		
			if(!$edit_field) { 		
		   
				$inv_dir = ($field_settings['upload_type'] == 'share') ? '' :  $SESS->userdata['username'].'/';
				$this->_get_upload_prefs($field_settings['preferences']);
				$folder_path = $this->upload_prefs['server_path'].$inv_dir;
				$folder_type = ($this->upload_prefs['allowed_types'] == "img") ? "image" : "file";
				$folder_url =  $this->upload_prefs['server_url'].$inv_dir;
			
				$f_name =  explode("[", $field_name);
				$name = "tb_".$f_name[0];
				
					if( isset($field_data) AND $field_data != '') {  
						$file_name =  basename($field_data);
						$field_data = ($file_name != $field_data) ? $field_data : $folder_url.$field_data; //ngen-file field support
					}
					if (session_id() == "") 
					{
						session_start(); 
					}	 
			  
			  

					$_SESSION[$name]  =  TRUE ;
					$_SESSION['language'] = ($LANG->line($SESS->userdata('language')) != '') ?  $LANG->line($SESS->userdata('language')) : $this->default_site_settings['language'];					
					$_SESSION[$name.'folder_path'] = $folder_path;
					$_SESSION[$name.'type']  = $folder_type;
					$_SESSION[$name.'folder_url']  = $folder_url;
					$_SESSION[$name.'file_maxsize'] = '';

					$_SESSION[$name.'allowupload'] = true;
					$_SESSION[$name.'allowedit'] = true;
					$_SESSION[$name.'allowdelete'] = true;
					$_SESSION[$name.'allowfolders'] = true;
					
					$_SESSION[$name.'cleanfilename'] = (isset($this->site_settings['cleanfilename'])) ?  $this->site_settings['cleanfilename'] : $this->default_site_settings['flt_image'];
					$_SESSION[$name.'pagination'] = (isset($this->site_settings['pagination'])) ?  $this->site_settings['pagination'] : $this->default_site_settings['pagination'];
					$_SESSION[$name.'image_view'] =(isset($this->site_settings['image_view'])) ?  $this->site_settings['image_view'] :$this->default_site_settings['flt_image'];
					$_SESSION[$name.'flt_image'] = (isset($this->site_settings['flt_image'])) ?  $this->site_settings['flt_image'] :$this->default_site_settings['flt_image'];
					$_SESSION[$name.'flt_media'] = (isset($this->site_settings['flt_media'])) ?  $this->site_settings['flt_media'] :$this->default_site_settings['flt_image'];
					$_SESSION[$name.'flt_file'] = (isset($this->site_settings['flt_file'])) ?  $this->site_settings['flt_file'] : $this->default_site_settings['flt_file'];
					$_SESSION[$name.'thumbquality'] = (isset( $field_settings['thumbquality'])) ?  $field_settings['thumbquality'] : $this->site_settings['thumbquality'];
					$_SESSION[$name.'imagequality'] = (isset( $field_settings['imagequality'])) ?  $field_settings['imagequality'] : $this->site_settings['imagequality'];
					$_SESSION[$name.'thumbsize'] = (isset( $field_settings['thumbsize'])) ?  $field_settings['thumbsize'] : $this->site_settings['thumbsize'];
					$_SESSION[$name.'resize_width'] = (isset( $field_settings['resize_width'])) ?  $field_settings['resize_width'] : $this->site_settings['resize_width'];
					$_SESSION[$name.'resize_height'] = (isset( $field_settings['resize_height'])) ?  $field_settings['resize_height'] : $this->site_settings['resize_height'];		
			
					if (in_array($SESS->userdata('group_id'), $this->upload_prefs['access']))
					{
					$_SESSION[$name.'allowupload'] =  false;
					$_SESSION[$name.'allowedit'] = false;
					$_SESSION[$name.'allowdelete'] = false;
					$_SESSION[$name.'allowfolders'] = false;
					}
				
				if ($field_settings['field_type'] == 'stand_alone' ){

				$_SESSION[$name.'integration']  = 'stand_alone';
						
			
				if( isset($field_data) AND $field_data) {
					$r .= '<div class="'.$field_name.'_input hide"><input name="'.$field_name.'"  class="mx_tinybrowser_field" value="'.$field_data.'" style="display:none;"/><a  name="'.$field_name.'" class="iframe tinyBrowser-add-button"  href="'.FT_URL.'mx_tinybrowser_field/tinybrowser/tinybrowser.php?type='.$folder_type.'" title="File Manager" >Choose</a></div>';
							
					$r .= '<div class="'.$field_name.'_display">';
					
						if ($this->_is_image($folder_path .'/'.$file_name) && file_exists($folder_path.'_thumbs/_'.$file_name)) {
						$r .= '<a class="fancybox" href="'.$field_data.'" title="'.$file_name.'"><img src="'.$folder_url."_thumbs/_".$file_name.'" title="'.$file_name.'" alt="'.$file_name.'"/></a>';
							}
						else	{
						$r .= '<strong class="filename">'.$file_name.'</strong>';
						}			
					$r .= ' <a  name="'.$field_name.'"  class="tinyBrowser-edit-button" title="Choose another file">Edit</a></div></div>';		
									

				}
				else{
						$r .= '<div class="'.$field_name.'_input">';
						$r .= '<input name="'.$field_name.'"  class="mx_tinybrowser_field" value="" style="display:none;"/>';
						$r .= '<a  name="'.$field_name.'" class="iframe tinyBrowser-add-button"  href="';
						$r .= (!$edit_field) ? FT_URL.'mx_tinybrowser_field/tinybrowser/tinybrowser.php?type='.$folder_type : '#';
						$r .= '" title="File Manager">Choose</a>';
						$r .= '</div>';
						$r .= '<div class="'.$field_name.'_display hide"></div>';		
				}

				$r .= '<div style="clear: both;"></div>';
			}
			else {

				$_SESSION[$name.'integration']  = 'tinymce';
				$_SESSION['tinymce_url']  =(isset($this->site_settings['tinymce_url'])) ?  $this->site_settings['tinymce_url'] : '';
			
				$conf_name = explode(".", $field_settings['config_file']);
				$r .= '';
				$r .= '<script type="text/javascript" src="'.FT_URL.'mx_tinybrowser_field/tinymce_config/'.$field_settings['config_file'].'" charset="utf-8"></script>';
				$r .= '<script type="text/javascript" src="'.FT_URL.'mx_tinybrowser_field/tinybrowser/tb_tinymce.js.php"></script>';


				$r .= "<textarea name='". $field_name ."' style='' rows='7' class='mx_".$conf_name[0]."' >" . $field_data . "</textarea>";
			
			}
			
			}
			
		}
		return $r;
	}

	/**
	 * Display Cell
	 * 
	 * @param  string  $cell_name      The cell's name
	 * @param  mixed   $cell_data      The cell's current value
	 * @param  array   $cell_settings  The cell's settings
	 * @return string  The cell's HTML
	 */
	function display_cell($cell_name, $cell_data, $cell_settings)
	{
		return $this->display_field($cell_name, $cell_data, $cell_settings);
	}

	/**
	 * Display Tag
	 *
	 * @param  array   $params          Name/value pairs from the opening tag
	 * @param  string  $tagdata         Chunk of tagdata between field tag pairs
	 * @param  string  $field_data      Currently saved field value
	 * @param  array   $field_settings  The field's settings
	 * @return string  relationship references
	 */
	/*function display_tag($params, $tagdata, $field_data, $field_settings)
	{
		global $TMPL;

	}*/
    //
	
		function thumb($params, $tagdata, $field_data, $field_settings)
	{
       return  dirname($field_data)."/_thumbs/_".basename($field_data);
	}
		function file_name($params, $tagdata, $field_data, $field_settings)
	{
		return  basename($field_data);
	}
	/**
	 * Display Field Settings
	 * 
	 * @param  array  $field_settings  The field's settings
	 * @return array  Settings HTML (cell1, cell2, rows)
	 */
		function display_field_settings($field_settings)
	{
		global $DSP, $LANG;
		$LANG->fetch_language_file('mx_tinybrowser_field');
		// Initialise a new instance of SettingsDisplay.
		$sd = new Fieldframe_SettingsDisplay();    
		
		$c = '';
		$c .= $sd->block($LANG->line('folder_tip'));
		$c .= $sd->row(array(
			$sd->label($LANG->line('preferences')),$this->_select_upload_locations($field_settings['preferences'])
			));				    
		
		$options = array (
		'share' => $LANG->line('shared'),
		'individual' =>$LANG->line('individual')
		);		
		$c .= $sd->row(array(
			$sd->label($LANG->line('upload_type')),
			$sd->select('upload_type', isset($field_settings['upload_type']) ? $field_settings['upload_type'] : $this->site_settings['upload_type'], $options)
			));				
			

		
		$c .= $sd->info_row($LANG->line('quality_tip'));		
				$c .= $sd->row(array(
			$sd->label($LANG->line('thumbquality')),
			$sd->text('thumbquality', isset( $field_settings['thumbquality']) ?  $field_settings['thumbquality'] : $this->site_settings['thumbquality'],array('size' => '2', 'maxlength' =>'2', 'width' => '20px'))
			));		
		$c .= $sd->row(array(
			$sd->label($LANG->line('imagequality')),
			$sd->text('imagequality', isset( $field_settings['imagequality']) ?  $field_settings['imagequality'] : $this->site_settings['imagequality'],array('size' => '2', 'maxlength' =>'2', 'width' => '20px'))
			));
			
	    $c .= $sd->info_row($LANG->line('size_tip'));
		$c .= $sd->row(array(
			$sd->label($LANG->line('thumbsize')),
			$sd->text('thumbsize', isset( $field_settings['thumbsize']) ?  $field_settings['thumbsize'] : $this->site_settings['thumbsize'],array('size' => '4', 'maxlength' =>'4', 'width' => '40px'))
			));						
		$c .= $sd->row(array(
			$sd->label($LANG->line('resize_width')),
			$sd->text('resize_width', isset( $field_settings['resize_width']) ?  $field_settings['resize_width'] : $this->site_settings['resize_width'], array('size' => '5', 'maxlength' =>'5', 'width' => '40px'))
			));					
		$c .= $sd->row(array(
			$sd->label($LANG->line('resize_height')),
			$sd->text('resize_height', isset( $field_settings['resize_height']) ?  $field_settings['resize_height'] : $this->site_settings['resize_height'], array('size' => '5', 'maxlength' =>'5', 'width' => '40px'))
			));

			// Close the table.


		   
		//  TinyMCE Config
			$c .= $sd->row(array(
			$sd->label($LANG->line('config_file')),$this->_get_dir_list(FT_PATH.'mx_tinybrowser_field/tinymce_config/',  isset($field_settings['config_file']) ? $field_settings['config_file'] : '')
			));			
	
		$c .= $sd->block_c();
			
		$options = array (
		'stand_alone' => 'TinyBrowser Stand Alone',
		'TinyMCE' => 'TinyMCE + TinyBrowser'
		);	
		$r = array(
			'cell1'									=> $sd->select('field_type', isset($field_settings['field_type']) ? $field_settings['field_type'] : $this->site_settings['field_type'], $options),
			'cell2'									=> $c,
			'formatting_available'	=> FALSE,
			'direction_available'		=> FALSE
			);
	    
		return $r;
	}
	

		function display_site_settings()
	{
		global $LANG;
		// Initialize a new instance of SettingsDisplay
		$SD = new Fieldframe_SettingsDisplay();
	 	
		$LANG->fetch_language_file('mx_tinybrowser_field');


	 
		// Define the initial textarea value
		$value = isset($this->site_settings['option_tmpl'])
		  ?  $this->site_settings['option_tmpl']
		  :  '';
	 
		// Define the textarea attributes
		$attr = array('rows' => '2');
		

		$r = $SD->block($LANG->line('folder_tip'));	
		$options = array  (
			"0" => $LANG->line('yes'),
			"1" => $LANG->line('no')
			);
			

		$r .= $SD->row(array(
			$SD->label($LANG->line('cleanfilename')),
			$SD->select('cleanfilename', isset($this->site_settings['cleanfilename']) ? $this->site_settings['cleanfilename'] : $this->default_site_settings['cleanfilename'], $options)
			));		
		$r .= $SD->block_c();	
		$r .= $SD->block($LANG->line('permitted_setting'));	
		
		$r .= $SD->row(array(
			$SD->label($LANG->line('flt_image')),
			$SD->text('flt_image', isset( $this->site_settings['flt_image']) ?  $this->site_settings['flt_image'] : $this->default_site_settings['flt_image'])
			));		

		$r .= $SD->row(array(
			$SD->label($LANG->line('flt_media')),
			$SD->text('flt_media', isset( $this->site_settings['flt_media']) ?  $this->site_settings['flt_media'] : $this->default_site_settings['flt_media'])
			));		

		$r .= $SD->row(array(
			$SD->label($LANG->line('flt_file')),
			$SD->text('flt_file', isset( $this->site_settings['flt_file']) ?  $this->site_settings['flt_file'] : $this->default_site_settings['flt_file'])
			));					
		
		$r .= $SD->block_c();	
		$r .= $SD->block($LANG->line('quality_tip'));				   
	
		$r .= $SD->row(array(
			$SD->label($LANG->line('thumbquality')),
			$SD->text('thumbquality', isset( $this->site_settings['thumbquality']) ?  $this->site_settings['thumbquality'] : $this->default_site_settings['thumbquality'],array('size' => '2', 'maxlength' =>'2', 'width' => '20px'))
			));		
		$r .= $SD->row(array(
			$SD->label($LANG->line('imagequality')),
			$SD->text('imagequality', isset( $this->site_settings['imagequality']) ?  $this->site_settings['imagequality'] : $this->default_site_settings['imagequality'],array('size' => '2', 'maxlength' =>'2', 'width' => '20px'))
			));
		
		$r .= $SD->block_c();	
		$r .= $SD->block($LANG->line('size_tip'));	

		$r .= $SD->row(array(
			$SD->label($LANG->line('thumbsize')),
			$SD->text('thumbsize', isset( $this->site_settings['thumbsize']) ?  $this->site_settings['thumbsize'] : $this->default_site_settings['thumbsize'],array('size' => '5', 'maxlength' =>'5', 'width' => '40px'))
			));						
		$r .= $SD->row(array(
			$SD->label($LANG->line('resize_width')),
			$SD->text('resize_width', isset( $this->site_settings['resize_width']) ?  $this->site_settings['resize_width'] : $this->default_site_settings['resize_width'],array('size' => '5', 'maxlength' =>'5','width' => '40px'))
			));					
		$r .= $SD->row(array(
			$SD->label($LANG->line('resize_height')),
			$SD->text('resize_height', isset( $this->site_settings['resize_height']) ?  $this->site_settings['resize_height'] : $this->default_site_settings['resize_height'],array('size' => '5', 'maxlength' =>'5','width' => '40px'))
			));
			
		$r .= $SD->block_c();	
		$r .= $SD->block($LANG->line('view'));
		$r .= $SD->row(array(
			$SD->label($LANG->line('pagination')),
			$SD->text('pagination', isset($this->site_settings['pagination']) ? $this->site_settings['pagination'] : $this->default_site_settings['pagination'],array('size' => '5', 'maxlength' =>'5', 'width' => '30px'))
			));

		$options = array  (
			"thumb" => $LANG->line('thumb'),
			"detail" => $LANG->line('detail')
			);
		$r .= $SD->row(array(
			$SD->label($LANG->line('image_view')),
			$SD->select('image_view', isset($this->site_settings['image_view']) ? $this->site_settings['image_view'] : $this->default_site_settings['image_view'], $options)
			));				

		$r .= $SD->block_c();
		

		$r .= $SD->block($LANG->line('TinyMCE settings'));
		
		$r .= $SD->row(array(
			$SD->label($LANG->line('TinyMCE_path')),
			$SD->text('tinymce_url', isset($this->site_settings['tinymce_url']) ? $this->site_settings['tinymce_url'] : $this->default_site_settings['tinymce_url'],array('size' => '256', 'maxlength' =>'256', 'width' => '100%'))
			));
		$r .= $SD->row(array(
			$SD->label($LANG->line('global_script')),
			$SD->textarea('script_block', isset($this->site_settings['script_block']) ? $this->site_settings['script_block'] : $this->default_site_settings['script_block'],array('rows' => '5','width' => '100%'))
			));
	 	
		$r .= $SD->block_c();	
		// Return the settings block
		return $r;
	}
	
		
	 // ...
 
	function show_full_control_panel_end($out)
	{
		global $IN;
		
		$r = '';
        $o = $this->get_last_call($out);
		$r .= "\n" . $this->site_settings['script_block'];
		$o = str_replace("<head>", "<head>" . $r, $o);
        return $o;
    }
 
    // ...
	/**	
	 * Display Cell Settings
	 * 
	 * @param  array  $cell_settings  The cell's settings
	 * @return string  Settings HTML
	 */
	function display_cell_settings($cell_settings)
	{
				global $DSP, $LANG;
		$LANG->fetch_language_file('mx_tinybrowser_field');
		// Initialise a new instance of SettingsDisplay.
		$sd = new Fieldframe_SettingsDisplay();    
		$options = array (
		'stand_alone' => 'TinyBrowser Stand Alone',
		'TinyMCE' => 'TinyMCE + TinyBrowser'
		);	
	
		$c = '';
		$c .= $sd->block($LANG->line('folder_tip'));
		$c .= $sd->row(array(
				$sd->select('field_type', isset($field_settings['field_type']) ? $field_settings['field_type'] : $this->site_settings['field_type'], $options)
			));			
			
		$c .= $sd->row(array(
			$sd->label($LANG->line('preferences')).$this->_select_upload_locations($cell_settings['preferences'])
			));				    
		
		$options = array (
		'share' => $LANG->line('shared'),
		'individual' =>$LANG->line('individual')
		);		
		$c .= $sd->row(array($sd->label($LANG->line('upload_type')).	
			$sd->select('upload_type', isset($cell_settings['upload_type']) ? $cell_settings['upload_type'] : $this->site_settings['upload_type'], $options)
			));				
			

		
		$c .= $sd->info_row($LANG->line('quality_tip'));		
				$c .= $sd->row(array(
			$sd->label($LANG->line('thumbquality')).
			$sd->text('thumbquality', isset( $cell_settings['thumbquality']) ?  $cell_settings['thumbquality'] : $this->site_settings['thumbquality'],array('size' => '2', 'maxlength' =>'2', 'width' => '20px'))
			));		
		$c .= $sd->row(array(
			$sd->label($LANG->line('imagequality')).
			$sd->text('imagequality', isset( $cell_settings['imagequality']) ?  $cell_settings['imagequality'] : $this->site_settings['imagequality'],array('size' => '2', 'maxlength' =>'2', 'width' => '20px'))
			));
			
	    $c .= $sd->info_row($LANG->line('size_tip'));
		$c .= $sd->row(array(
			$sd->label($LANG->line('thumbsize')).
			$sd->text('thumbsize', isset( $cell_settings['thumbsize']) ?  $cell_settings['thumbsize'] : $this->site_settings['thumbsize'],array('size' => '4', 'maxlength' =>'4', 'width' => '40px'))
			));						
		$c .= $sd->row(array(
			$sd->label($LANG->line('resize_width')).
			$sd->text('resize_width', isset( $cell_settings['resize_width']) ?  $cell_settings['resize_width'] : $this->site_settings['resize_width'], array('size' => '5', 'maxlength' =>'5', 'width' => '40px'))
			));					
		$c .= $sd->row(array(
			$sd->label($LANG->line('resize_height')).
			$sd->text('resize_height', isset( $cell_settings['resize_height']) ?  $cell_settings['resize_height'] : $this->site_settings['resize_height'], array('size' => '5', 'maxlength' =>'5', 'width' => '40px'))
			));
			
		//  TinyMCE Config
		$c .= $sd->row(array(
		$sd->label($LANG->line('config_file')),$this->_get_dir_list(FT_PATH.'mx_tinybrowser_field/tinymce_config/',  isset($field_settings['config_file']) ? $field_settings['config_file'] : '')
		));						

			// Close the table.
		$c .= $sd->block_c();

		
	/*	$r = '<label class="itemWrapper">'
		   . $DSP->qdiv('defaultBold', $LANG->line('file_options_label'))
		   . $this->_select_upload_locations($cell_settings['options'])
		   . '</label>';
*/
		   return $c;
	}	
	//

	
	//
	// Retrieves the upload preferences
	//
	function _get_upload_prefs($u_id)
	{
		global $DB, $FNS, $PREFS;			
	
		if( !isset($this->upload_prefs['loc_id']) || $this->upload_prefs['loc_id'] != $u_id ) {
			$query = $DB->query("SELECT * FROM exp_upload_prefs WHERE id = $u_id");	
			$this->upload_prefs['loc_id'] = $u_id;
			$this->upload_prefs['server_path'] = $query->row['server_path'];
			$this->upload_prefs['server_uri'] = parse_url($query->row['url'], PHP_URL_PATH);
			$this->upload_prefs['server_url'] = $query->row['url'];
			$this->upload_prefs['allowed_types'] = $query->row['allowed_types'];
			$this->upload_prefs['max_file_size'] = $query->row['max_size'];
			$query = $DB->query("SELECT member_group FROM exp_upload_no_access WHERE upload_id = $u_id");
			$this->upload_prefs['access'] = array();
			if ($query->num_rows > 0)
			{
				$this->upload_prefs['access'][]  = $query->row['member_group'];
			}
			
		}
			 
	}	
	
	
    //
	// Create upload_locations list
	//
	//	
	function _select_upload_locations($current_option)
	{
		global $DB, $PREFS;

		$result = "<div class='itemWrapper'><select name=\"preferences\"><option value=\"\"></option>";	
		$upload_loc_q = $DB->query("SELECT id, name FROM exp_upload_prefs WHERE site_id = " . $PREFS->ini('site_id') . " ORDER BY name ASC");
		
		foreach($upload_loc_q->result as $upload_loc)
		{
			$selected = ($upload_loc['id'] == $current_option) ? " selected=\"true\"" : "";
			$result .= "<option value=\"{$upload_loc['id']}\"$selected>{$upload_loc['name']}</option>";
		}
		
		$result .= "</select></div></div>";
		
		return $result;
	}
	//

	
	/**
	 * Return human readable sizes
	 *
	 * @author      Aidan Lister <aidan@php.net>
	 * @version     1.3.0
	 * @link        http://aidanlister.com/repos/v/function.size_readable.php
	 * @param       int     $size        size in bytes
	 * @param       string  $max         maximum unit
	 * @param       string  $system      'si' for SI, 'bi' for binary prefixes
	 * @param       string  $retstring   return string format
	 */
	function _size_readable($size, $max = null, $system = 'si', $retstring = '%01.2f %s')
	{
		// Pick units
		$systems['si']['prefix'] = array('B', 'K', 'MB', 'GB', 'TB', 'PB');
		$systems['si']['size']   = 1000;
		$systems['bi']['prefix'] = array('B', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB');
		$systems['bi']['size']   = 1024;
		$sys = isset($systems[$system]) ? $systems[$system] : $systems['si'];

		// Max unit to display
		$depth = count($sys['prefix']) - 1;
		if ($max && false !== $d = array_search($max, $sys['prefix'])) {
			$depth = $d;
		}

		// Loop
		$i = 0;
		while ($size >= $sys['size'] && $i < $depth) {
			$size /= $sys['size'];
			$i++;
		}

		return sprintf($retstring, $size, $sys['prefix'][$i]);
	}

/*	function _findexts ($filename)
	{
	$filename = strtolower($filename) ;
	$exts = split("[/\\.]", $filename) ;
	$n = count($exts)-1;
	$exts = $exts[$n];
	return $exts;
	} 
*/
	//
	//
	//
	function _is_image($file) {
		$is_image = false;
		$file = trim($file);	

		if  (file_exists($file)) {
		if  (exif_imagetype($file) ) {
			$is_image = true;
		}
		return $is_image;
		}
	}
	
	function _get_dir_list ($directory,$current_option) {
		// create an array to hold directory list
		$results = array();
	 
		// create a handler for the directory
		$handler = opendir($directory);
	 
		// keep going until all files in directory have been read
		while ($file = readdir($handler)) {
	 	    $f_name = explode(".", $file);
			// if $file isn't this directory or its parent,
			// add it to the results array
			if ($file != '.' && $file != '..'  &&  $f_name[1]  == 'js')
				$results[] = $file;
		}



		// tidy up: close the handler
		closedir($handler);
	 
			$result = "<div class='itemWrapper'><select name=\"config_file\"><option value=\"\"></option>";	
			
			foreach($results as $conf_file)
			{
				$selected = ($conf_file == $current_option) ? " selected=\"true\"" : "";
				$result .= "<option value=\"{$conf_file}\"$selected>{$conf_file}</option>";
			}
			
			$result .= "</select></div></div>";
			
		return $result;
	}
}


/* End of file ft.mx_tinybrowser_field.php */
/* Location: ./system/fieldtypes/mx_tinybrowser_field/ft.mx_tinybrowser_field.php */